@@ -9,7 +9,8 @@ LEFT_KEYS = {
     "SKWR": "J",
     "SH":   "SH",
     "SPW":  [(r"int", "INT"), (r"ent", "ENT"), ("", "SB")],
-    "STK":  [(r"d[ie][sz]", "DS"), ("", "SD")],
+    "STKPW": [(r"(s|[aeiou])[a-z]{0,5}g", "SG"), (r"d[ie][szc][a-z]{0,5}b", "DSB"), ("", "STKPW")],
+    "STK":  [(r"d[ie][szc]", "DS"), ("", "SD")],
     "S":    "S",
     "THR":  [(r"th[a-z]{0,5}r", "THR"), ("", "TL")],
     "TPHR": [(r"t[a-z]{0,5}p[aeiou]?l", "TPL"), (r"t[a-z]{0,5}m[a-z]{0,5}r", "TMR"), (r"n[a-z]{0,5}r", "NR"), ("", "FL")],
@@ -24,10 +25,11 @@ LEFT_KEYS = {
     "KWR":  "Y",
     "KH":   "CH",
     "KW":   [(r"q[^uw]", "Q"), ("", "KW")],
+    "KPH": [(r"[ck][aeiou]?mm?", "KM"), (r"x[a-z]{0,5}h", "XH"), ("", "KPH")],
     "KPW":  [(r"imp", "IMP"), (r"emp", "EMP"), ("", "KB")],
-    "KP":   [(r"[ie]x", "X"), ("", "KP")],
+    "KP":   [(r"[ie]x", "X"), (r"cc", "X"), ("", "KP")],
     "K":    "K",
-    "PHR":  [(r"m.*?r", "MR"), ("", "PL")],
+    "PHR":  [(r"pl", "PL"), (r"m[aeiou]{0,2}r", "MR"), ("", "PHR")],
     "PH":   "M",
     "PW":   "B",
     "P":    "P",
@@ -81,31 +83,34 @@ MID_KEYS = {
 
 
 RIGHT_KEYS = {
+    "FPB":    [(r"(s|z|th|f)[a-z]{0,5}n", "FN"), ("", "FPB")],
     "FRB":    [(r"[fv][a-z]{0,5}sh", "FSH"), (r"[fv][a-z]{0,5}r[a-z]{0,5}b", "FRB"), ("", "RV")],
     "FRPB":   [(r"nch", "NCH"), (r"rch", "RCH"), ("", "FRN")],
-    "FP":     "CH",
+    "FP":     [(r"(s|z|th|f)p", "FP"), (r"ch|c", "CH"), ("", "FP")],
     "FRP":    [(r"mp", "MP"), ("", "FRP")],
     "FR":     [(r"rf", "RF"), ("", "FR")],
     "F":      "F",
     "RPBLGZ": [(r"rn[aeiou]?l[a-z]{0,5}[zs]ing", "RNLZG"), ("", "RJZ")],
     "RPBG":   [(r"r[a-z]{0,5}p[a-z]{0,5}[ck]", "RPK"), ("", "RNG")],
     "RPBLG":  [(r"rn[aeiou]?l[a-z]{0,5}g", "RNLG"), ("", "RJ")],
-    "RB":     [(r"r[a-z]{0,5}b", "RB"), ("", "SH")],
+    "RBG":    [(r"r[a-z]{0,5}b[a-z]{0,5}g", "RBG"), (r"(sh|ti|ci|s)[a-z]{0,5}g", "SHG"), ("", "RK")],
+    "RB":     [(r"r[a-z]{0,5}b", "RB"), (r"(sh|ti|ci|s)", "SHG"), ("", "RB")],
     "RPB":    "RN",
     "R":      "R",
     "PLT":    [(r"m[a-z]{0,5}nt", "MNT"), (r"p[aoiyeu]*l", "PLT"), ("", "MT")],
+    "PBGS":    [(r"p[a-z]{0,5}[ck]s", "PKS"), (r"n[aeiou]{0,2}[tsc][ie][ao]n|n[aeiou]{0,2}sh[eu]n", "NSHUN"), ("", "NGS")],
     "PBG":    [(r"p[a-z]{0,5}[ck]", "PK"), ("", "NG")],
     "PBLG":   [(r"n[a-z]{0,5}lo?g", "NLJ"), (r"n[a-z]{0,5}lch", "NLCH"), ("", "J")],
     "PL":     [(r"p[aoiyeu]*l", "PL"), ("", "M")],
     "PB":     "N",
     "P":      "P",
-    "BGS":    [(r"[ck][aeiou]?[tsc][ie][ao]n|[ck]sh[eu]n", "KSHUN"), (r"b[a-z]{0,5}[tsc][ie][ao]n|b[a-z]{0,5}sh[eu]n", "BSHUN"), (r"b[a-z]{0,5}gs", "BGS"), (r"x", "X"), ("", "KS")],
+    "BGS":    [(r"x[aeiou]?tion", "KSHUN"), (r"x", "X"), (r"[ck][aeiou]?[tsc][ie][ao]n|[ck]sh[eu]n", "KSHUN"), (r"b[a-z]{0,5}[tsc][ie][ao]n|b[a-z]{0,5}sh[eu]n", "BSHUN"), (r"b[a-z]{0,5}gs", "BGS"), ("", "KS")],
     "BG":     [(r"b[a-z]{0,5}g", "BG"), ("", "K")],
     "B":      "B",
     "LGS":    [(r"l[a-z]{0,5}[tsc][ie][ao]n|l[a-z]{0,5}sh[eu]n", "LSHUN"), (r"[tsc][ie][ao]n[a-z]{0,5}l|sh[eu]n[a-z]{0,5}l", "SHUNL"), (r"lo?gs", "LJS"), (r"lchs", "LCHS"), ("", "LGS")],
     "LG":     [(r"lo?g", "LJ"), (r"lch", "LCH"), ("", "LG")],
     "L":      "L",
-    "GS":     [(r"[tsc][ie][ao]n|sh[eu]n", "SHUN"), ("", "GS")],
+    "GS":     [(r"[tscg]h?[ie][ao]n|sh[eu]n", "SHUN"), ("", "GS")],
     "G":      "G",
     "T":      "T",
     "S":      "S",
@@ -124,7 +129,7 @@ RIGHT_STARRED = {
 }
 
 # Returns: Remaining Chord, Remaining Word, Partial Pseudo Steno
-def eat(chord: str, word: str, key_map: dict, star_key_map: dict, starred: bool) -> (str, str, str):
+def eat(chord: str, word: str, key_map: dict, star_key_map: dict, starred: bool) -> Tuple[str, str, str]:
     out_chord = ""
     for key, value in key_map.items():
         if chord.startswith(key):
@@ -143,8 +148,7 @@ def eat(chord: str, word: str, key_map: dict, star_key_map: dict, starred: bool)
                     else:
                         return out_chord, word, psd
 
-
-def to_pseudo_single(chord: str, word: str) -> (str, str):
+def to_pseudo_single(chord: str, word: str) -> Tuple[str, str]:
     if chord == "#":
         return "#", word
 
@@ -233,3 +237,36 @@ def format_pseudo(outline: Tuple[str, ...], word: str) -> Tuple[str, ...]:
         stroke_builder.append(pseudo)
     
     return tuple(stroke_builder)
+
+
+test_list = [
+    ("access", "KPES"),
+    ("execution", "EBGS/KAOUGS"),
+    ("taxation", "TA*EUBGS"),
+    ("commune", "KPHAOUPB"),
+    ("simpler", "SPHRER"),
+    ("decision", "STKEUGS"),
+    ("distinguish", "STKPWEUGS"),
+    ("again", "STKPWEPB"),
+    ("region", "RAOEGS"),
+    ("fashion", "TPAGS"),
+    ("donation", "TKOEPBGS"),
+    ("mention", "PHEPBGS"),
+    ("absorption", "SPWORBGS"),
+    ("dark", "TKARBG"),
+    ("everybody", "EFRB"),
+    ("several", "SEFRL"),
+    ("silver", "SEUFRL"),
+    ("disposition", "TKEUFPGS"),
+    ("suspicion", "SUFPGS"),
+    ("resistant", "REUFPBT"),
+    ("defend", "TKEFPBD"),
+    ("whisper", "WHEUFP/*ER"),
+    ("helpful", "HEFPL"),
+    ("evidence based medicine", "PWEFPL"),
+]
+
+if __name__ == "__main__":
+    for (word, outline) in test_list:
+        outline_s = tuple(outline.split("/"))
+        print(word, format_pseudo(outline_s, word))
